# API Reference

Here you can find the API reference for the `kernpy` package. The reference contains a detailed description of the `kernpy` API. The reference describes how the methods work and which parameters can be used. 

Find the basics of the `kernpy` package in the [Tutorial](get-started/tutorial.md).

::: kernpy

## Modules

::: kernpy.core

::: kernpy.util




